@@ -101,4 +101,4 @@ LearnerClassifRpart = R6Class("LearnerClassifRpart", inherit = LearnerClassif,
 )
 
 #' @include mlr_learners.R
-mlr_learners$add("classif.rpart", LearnerClassifRpart)
+mlr_learners$add("classif.rpart", function() LearnerClassifRpart$new())
