@@ -23,6 +23,7 @@
 #' @template param_learner_properties
 #' @template param_data_formats
 #' @template param_packages
+#' @template param_label
 #' @template param_man
 #'
 #' @template seealso_learner
@@ -39,9 +40,10 @@ LearnerRegr = R6Class("LearnerRegr", inherit = Learner,
   public = list(
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
-    initialize = function(id, param_set = ps(), predict_types = "response", feature_types = character(), properties = character(), data_formats = "data.table", packages = character(), man = NA_character_) {
+    initialize = function(id, param_set = ps(), predict_types = "response", feature_types = character(), properties = character(), data_formats = "data.table", packages = character(), label = NA_character_, man = NA_character_) {
       super$initialize(id = id, task_type = "regr", param_set = param_set, feature_types = feature_types,
-        predict_types = predict_types, properties = properties, data_formats = data_formats, packages = packages, man = man)
+        predict_types = predict_types, properties = properties, data_formats = data_formats, packages = packages,
+        label = label, man = man)
     }
   )
 )
