@@ -31,6 +31,11 @@
 #' * `as.data.table(t)`\cr
 #'   [Task] -> [data.table::data.table()]\cr
 #'   Returns the complete data as [data.table::data.table()].
+#' * `head(t)`\cr
+#'   Calls [head()] on the task's data.
+#' * `summary(t)`\cr
+#'   Calls [summary()] on the task's data.
+#'
 #'
 #' @section Task mutators:
 #' The following methods change the task in-place:
@@ -65,7 +70,7 @@
 #'
 #' # Add new column "foo"
 #' task$cbind(data.frame(foo = 1:344))
-#' task$head()
+#' head(task)
 Task = R6Class("Task",
   public = list(
     #' @template field_id
@@ -114,18 +119,22 @@ Task = R6Class("Task",
         self$backend = assert_backend(backend)
       }
 
+      cn = self$backend$colnames
+      rn = self$backend$rownames
+
+      if (allow_utf8_names()) {
+        assert_names(cn, "unique", .var.name = "column names")
+        if (any(grepl("%", cn, fixed = TRUE))) {
+          stopf("Column names may not contain special character '%%'")
+        }
+      } else {
+        assert_names(cn, "strict", .var.name = "column names")
+      }
+
       self$col_info = col_info(self$backend)
       self$col_info$label = NA_character_
       self$col_info$fix_factor_levels = FALSE
 
-      if (allow_utf8_names()) {
-        assert_names(self$col_info$id, "unique", .var.name = "feature names")
-        if (any(grepl("%", self$col_info$id, fixed = TRUE))) {
-          stopf("Feature names may not contain special character '%%'")
-        }
-      } else {
-        assert_names(self$col_info$id, "strict", .var.name = "feature names")
-      }
       assert_subset(self$col_info$type, mlr_reflections$task_feature_types, .var.name = "feature types")
       pmap(self$col_info[, c("id", "levels")],
         function(id, levels) {
@@ -135,8 +144,7 @@ Task = R6Class("Task",
       )
 
       cn = self$col_info$id # note: this sorts the columns!
-      rn = self$backend$rownames
-      private$.row_roles = list(use = rn, holdout = integer())
+      private$.row_roles = list(use = rn, holdout = integer(), early_stopping = integer())
       private$.col_roles = named_list(mlr_reflections$task_col_roles[[task_type]], character())
       private$.col_roles$feature = setdiff(cn, self$backend$primary_key)
       self$extra_args = assert_list(extra_args, names = "unique")
@@ -159,7 +167,7 @@ Task = R6Class("Task",
     #' @param ... (ignored).
     print = function(...) {
       catf("%s (%i x %i)%s", format(self), self$nrow, self$ncol,
-        if (is.na(self$label)) "" else paste0(": ", self$label))
+        if (is.null(self$label) || is.na(self$label)) "" else paste0(": ", self$label))
       catf(str_indent("* Target:", self$target_names))
       catf(str_indent("* Properties:", self$properties))
 
@@ -285,11 +293,9 @@ Task = R6Class("Task",
     #' @param n (`integer(1)`).
     #' @return [data.table::data.table()] with `n` rows.
     head = function(n = 6L) {
-      assert_has_backend(self)
-      assert_count(n)
+      assert_number(n, na.ok = FALSE)
       ids = head(private$.row_roles$use, n)
-      cols = c(private$.col_roles$target, private$.col_roles$feature)
-      self$data(rows = ids, cols = cols)
+      self$data(rows = ids)
     },
 
     #' @description
@@ -362,6 +368,7 @@ Task = R6Class("Task",
     #' the object in its previous state.
     select = function(cols) {
       assert_has_backend(self)
+      assert_character(cols)
       assert_subset(cols, private$.col_roles$feature)
       private$.col_roles$feature = intersect(private$.col_roles$feature, cols)
       invisible(self)
@@ -606,7 +613,7 @@ Task = R6Class("Task",
     #' @description
     #' Set levels for columns of type `factor` and `ordered` in field `col_info`.
     #' You can add, remove or reorder the levels, affecting the data returned by
-    #' `$data()`, `$head()` and `$levels()`.
+    #' `$data()` and `$levels()`.
     #' If you just want to remove unused levels, use `$droplevels()` instead.
     #'
     #' Note that factor levels which are present in the data but not listed in the task as
@@ -760,7 +767,14 @@ Task = R6Class("Task",
     #'
     #' - `"use"`: Use in train / predict / resampling.
     #' - `"holdout"`: Observations are hold back unless explicitly queried.
-    #'   Can be used, e.g., as truly independent holdout set.
+    #'   Can be used, e.g., as truly independent holdout set:
+    #'
+    #'   1. Add `"holdout"` to the `predict_sets` of a [Learner].
+    #'   2. Configure a [Measure] to use the `"holdout"` set by updating its `predict_sets` field.
+    #'
+    #' - `"early_stopping"`: Observations are hold back unless explicitly queried.
+    #'   Can be queried by a [Learner] to determine a good iteration to stop by evaluating the performance
+    #'   on external data, e.g. the XGboost learner in \CRANpkg{mlr3learners} for parameter `nrounds`.
     #'
     #' `row_roles` is a named list whose elements are named by row role and each element is an `integer()` vector of row ids.
     #' To alter the roles, just modify the list, e.g. with  \R's set functions ([intersect()], [setdiff()], [union()], \ldots).
@@ -1045,14 +1059,27 @@ col_info.DataBackend = function(x, ...) { # nolint
 
 #' @export
 as.data.table.Task = function(x, ...) { # nolint
-  x$head(x$nrow)
+  x$data()
 }
 
 #' @export
-format_list_item.Task = function(x, ...) { # nolint
-  sprintf("<tsk:%s>", x$id)
+head.Task = function(x, n = 6L, ...) { # nolint
+  assert_number(n, na.ok = FALSE)
+  x$data(rows = head(x$row_ids, n))
 }
 
+#' @export
+tail.Task = function(x, n = 6L, ...) { # nolint
+  assert_number(n, na.ok = FALSE)
+  x$data(rows = tail(x$row_ids, n))
+}
+
+# #' @export
+# format_list_item.Task = function(x, ...) { # nolint
+#   print("HIIII")
+#   sprintf("<tsk:%s>", x$id)
+# }
+
 task_rm_backend = function(task) {
   # fix task hash
   ee = get_private(task)
@@ -1068,7 +1095,7 @@ task_rm_backend = function(task) {
 
 #' @export
 rd_info.Task = function(obj, section) { # nolint
-  c("",
+  x = c("",
     sprintf("* Task type: %s", rd_format_string(obj$task_type)),
     sprintf("* Dimensions: %ix%i", obj$nrow, obj$ncol),
     sprintf("* Properties: %s", rd_format_string(obj$properties)),
@@ -1076,4 +1103,10 @@ rd_info.Task = function(obj, section) { # nolint
     sprintf("* Target: %s", rd_format_string(obj$target_names)),
     sprintf("* Features: %s", rd_format_string(obj$feature_names))
   )
+  paste(x, collapse = "\n")
+}
+
+#' @export
+summary.Task = function(object, limit = object$nrow, ...) {
+  summary(head(object, limit))
 }
